@@ -1,4 +1,4 @@
-def print_lol(the_list, tabcount):
+def print_lol(the_list, tabcount=0):
 	for each_item in the_list:
 		if isinstance(each_item, list):
 			print_lol(each_item, tabcount+1)
